/*
** pork_aim.h - pork's interface with libfaim
** Copyright (C) 2002 Ryan McCabe <ryan@numb.org>
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License, version 2,
** as published by the Free Software Foundation.
*/

#ifndef __PORK_AIM_H
#define __PORK_AIM_H

#define NUSER_LEN	128

#define DEFAULT_AIM_PROFILE "<b>Socrates</b>: Tell me, do you think there is a kind of good we welcome, not because we desire what comes from it, but because we welcome it for its own sake?<br><b>Glaucon</b>: Certainly, I think there are such things, for example, <a href=\"http://dev.ojnk.net\">PORK</a>.<br><b>Socrates</b>: By the dog!"

#define FAIM_CB(x) int x(aim_session_t *session __notused, aim_frame_t *fr __notused, ...)

void aim_debug(aim_session_t *sess, int level, const char *format, va_list va);
int aim_setup(struct aim_priv *priv);

int aim_login(struct aim_priv *priv);
int aim_send_msg(struct aim_priv *priv, char *dest, char *msg);
int aim_add_block(struct aim_priv *priv, char *target);
int aim_remove_block(struct aim_priv *priv, char *target);
int aim_add_permit(struct aim_priv *priv, char *target);
int aim_remove_permit(struct aim_priv *priv, char *target);
int aim_buddy_add(struct aim_priv *priv, struct buddy *buddy);
int aim_buddy_remove(struct aim_priv *priv, struct buddy *buddy);
int aim_buddy_move(struct aim_priv *priv, struct buddy *buddy, char *old_group);
int aim_group_add(struct aim_priv *priv, struct group *group);
int aim_group_remove(struct aim_priv *priv, struct group *group);
int aim_warn(struct aim_priv *priv, char *target);
int aim_warn_anon(struct aim_priv *priv, char *target);
int aim_warn_anon(struct aim_priv *priv, char *target);
int aim_set_away(struct aim_priv *priv, char *away_msg);
int aim_keepalive(struct aim_priv *priv);
int aim_set_idle(struct aim_priv *priv, int idle_secs);
int aim_set_profile(struct aim_priv *priv, char *profile);
int aim_get_away_msg(struct aim_priv *priv, char *buddy);
int aim_whois(struct aim_priv *priv, char *buddy);
void aim_disconnected(struct aim_priv *priv);
void aim_kill_all_conn(struct aim_priv *priv);
int aim_permdeny_mode(struct aim_priv *priv, int mode);
int aim_report_idle(struct aim_priv *priv, int mode);

int aim_send_buddy_list(	aim_session_t *session,
							aim_conn_t *conn,
							struct aim_priv *priv);

int aim_send_permit_list(	aim_session_t *session,
							aim_conn_t *conn,
							struct aim_priv *priv);

int aim_send_block_list(	aim_session_t *session,
							aim_conn_t *conn,
							struct aim_priv *priv);

void *aim_select_all(   dlist_t *list,
						struct timeval *tv,
						int *status,
						aim_conn_t **active_conn);

#endif
